@@ -93,7 +93,7 @@ sub _connect ( $self, $cb ) {
     weaken $self;
 
     Pcore::WebSocket->connect_ws(
-        q[]              => "ws://$self->{chrome}->{host}:$self->{chrome}->{port}/devtools/page/$self->{id}",
+        "ws://$self->{chrome}->{host}:$self->{chrome}->{port}/devtools/page/$self->{id}",
         max_message_size => 0,
         compression      => 0,
         connect_timeout  => 1000,
